diff gcc/testsuite/g++.old-deja/g++.law/ctors9.C @ 145:1830386684a0

gcc-9.2.0
author anatofuz
date Thu, 13 Feb 2020 11:34:05 +0900
parents 04ced10e8804
children
line wrap: on
line diff
--- a/gcc/testsuite/g++.old-deja/g++.law/ctors9.C	Thu Oct 25 07:37:49 2018 +0900
+++ b/gcc/testsuite/g++.old-deja/g++.law/ctors9.C	Thu Feb 13 11:34:05 2020 +0900
@@ -20,7 +20,7 @@
 { }
 
 
-struct var_Foo: public Foo // { dg-message "note" }  base.*// ERROR -  in class.*
+struct var_Foo: public Foo // { dg-message "note" "" { target c++17_down } }  base.*// ERROR -  in class.*
 {
   var_Foo* operator-> () {return this;}
 };
@@ -32,7 +32,7 @@
 
 int main()
 {
-  var_Foo b(2);// { dg-error "match" } 
+  var_Foo b(2);// { dg-error "match" "" { target c++17_down } } 
   b->a = 0;
   int x = blort(b);
   return x;